unit QuesUnit;

// by Randy Beck
//    1, July 2008
//   http://www.randybeck.com
//   email:  rb@randybeck.com
//
//  QuestionBox asks a question and lets the user pick from up to five options:
//
//    function  QuestionBox(AQuestion,AResponses: string) : integer;
//
//  AQuestion is simply a string with the question you ask.  You can insert
//  line feeds with the ^J character like this:
//      'Where would you'^J'like to go today?'
//
//  AResponses is one string holding up to four responses separated by apostrophes (";").
//  The responses may include ampersands ("&") to indicate hotkeys.
//
//  It returns the numbers 1 through 5, based on the option selected,
//  or 0 if the user cancelled or pressed Esc.
//
//  Case QuestionBox('What would you like to do?',
//                   'Sail to &Bermuda;Fly to &Paris;Launch to &Orbit')
//  of
//    1:   Dest := 'Bermuda';
//    2:   Dest := 'Paris';
//    3:   Dest := 'Orbit';
//  else   Exit;  { user cancelled }
//  end;
//
//  The dialog box's caption is "Question" but it can be modified at the
//  global variable QuestionBoxCaption.
//
//  The height of the question area can be modified at QuestionBoxPanelHeight.

interface

uses
  SysUtils, WinTypes, WinProcs, Forms, ExtCtrls,
  StrUtils, Classes, Controls, StdCtrls;

type
  TQuesBox = class(TForm)
    MainPanel: TPanel;
    BottomPanel: TPanel;
    TopPanel: TPanel;
    Panel3: TPanel;
    QuestionMemo: TMemo;
    Panel4: TPanel;
    CancelBtn: TButton;
    ButtonsPanel: TPanel;
    Button1: TButton;
    Button2: TButton;
    Button3: TButton;
    Button4: TButton;
    Button5: TButton;
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
    procedure Button5Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    Answer: integer;
  end;


var  QuestionBoxCaption: string = 'Question';
     QuestionBoxPanelHeight: integer = 100;

function  QuestionBox(AQuestion,AResponses: string) : integer;


implementation

{$R *.DFM}

function  QuestionBox(AQuestion,AResponses: string) : integer;
var  i,j: integer;
     S: string;
     Q: TQuesBox;

    procedure SetButton(ABtn: TButton);
    begin
      If S = '' then
        ABtn.Visible := FALSE
      else begin
        ABtn.Width := Q.ButtonsPanel.Width - (ABtn.Left + 12);
        If pos(';',S) > 1 then
        begin
          ABtn.Caption := copy(S, 1, pred(pos(';',S)));
          Delete(S, 1, pos(';',S));
        end
        else begin
          ABtn.Caption := S;
          S := '';
          Q.Height :=
                  (Q.Height - Q.MainPanel.Height)
                + (Q.TopPanel.Height + ABtn.Top + ABtn.Height)
                +  Q.Button1.Left;
        end;
      end;
    end;

begin

  Result := 0;
  Q := TQuesBox.Create(nil);
  try
    Q.TopPanel.Height := QuestionBoxPanelHeight;
    Q.Caption := QuestionBoxCaption;
    Q.QuestionMemo.Lines.Text := AQuestion;
    S := AResponses;
    SetButton(Q.Button1);
    SetButton(Q.Button2);
    SetButton(Q.Button3);
    SetButton(Q.Button4);
    SetButton(Q.Button5);
    Q.ActiveControl := Q.Button1;
    Q.ShowModal;
    Result := Q.Answer;
  finally
    Q.Free;
  end;
end;


procedure TQuesBox.Button1Click(Sender: TObject);
begin
  Answer := 1;
  ModalResult := mrOK;
end;

procedure TQuesBox.Button2Click(Sender: TObject);
begin
  Answer := 2;
  ModalResult := mrOK;
end;

procedure TQuesBox.Button3Click(Sender: TObject);
begin
  Answer := 3;
  ModalResult := mrOK;
end;

procedure TQuesBox.Button4Click(Sender: TObject);
begin
  Answer := 4;
  ModalResult := mrOK;
end;

procedure TQuesBox.Button5Click(Sender: TObject);
begin
  Answer := 5;
  ModalResult := mrOK;
end;

end.

